@@ -104,7 +104,6 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	LineList = gtk_list_store_new(7, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_BOOLEAN);
 	GtkTreeView* tree = (GtkTreeView*)glade_xml_get_widget(xml, "lineslist");
 	Selection = gtk_tree_view_get_selection(tree);
-	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
 	gtk_tree_view_set_model(tree, GTK_TREE_MODEL(LineList));
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -262,6 +261,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 				break;
 		}
 	}
+	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
 	if (!m_Lines->len)gtk_widget_set_sensitive(DeleteAllBtn, false);
 }
 
@@ -322,7 +322,7 @@ bool gcLinesDlg::Apply()
 	//Add new lines from array
 	
 	struct LineStruct* s;
-	for (int i = 0; i  < m_Lines->len; i++)
+	for (int i = 0; i  < (int) m_Lines->len; i++)
 	{
 		s = &g_array_index(m_Lines, struct LineStruct, i);
 		Lines->push_back(new CrystalLine((s->duplicated)? normal: gcu::unique, s->x1, s->y1, s->z1, s->x2, s->y2, s->z2, s->r, (float)s->Red, (float)s->Green, (float)s->Blue, (float)s->Alpha));
@@ -420,7 +420,7 @@ void gcLinesDlg::OnEdited(GtkCellRendererText *cell, const gchar *path_string, c
 
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(LineList), &iter, path);
 
-	gint i = gtk_tree_path_get_indices (path)[0], j  = (long)g_object_get_data(G_OBJECT (cell), "column");
+	gint j  = (long)g_object_get_data(G_OBJECT (cell), "column");
 	double x = atof(new_text);
 	gtk_list_store_set(LineList, &iter, j, x, -1);
 	switch (j)
